<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package WP_Blog
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'wp-blog' ); ?></a>

	<header id="masthead" class="site-header">

		<div class="site-topbar">
            <div class="container">
                <nav id="site-navigation" class="main-navigation">
                    <button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><i class="fa fa-bars" aria-hidden="true"></i> <?php esc_html_e( 'Menu', 'wp-blog' ); ?></button>
					<?php
					wp_nav_menu( array(
						'theme_location' => 'menu-1',
						'menu_id'        => 'primary-menu',
					) );
					?>
                </nav><!-- #site-navigation -->

                <div class="social-media-gadget">
                    <ul>
	                    <?php wp_blog_social_media(); ?>
                    </ul>
                </div>


            </div>
        </div>

        <div class="site-branding">
            <div class="container">
				<?php
				the_custom_logo();
				if ( is_front_page() && is_home() ) :
					?>
                    <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
					<?php
				else :
					?>
                    <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
					<?php
				endif;
				$wp_blog_description = get_bloginfo( 'description', 'display' );
				if ( $wp_blog_description || is_customize_preview() ) :
					?>
                    <p class="site-description"><?php echo $wp_blog_description; /* WPCS: xss ok. */ ?></p>
				<?php endif; ?>
            </div>
        </div><!-- .site-branding -->

	</header><!-- #masthead -->

	<?php if ( is_archive() ) { ?>
        <header class="page-header archive-header">
            <div class="container">
				<?php
				the_archive_title( '<h1 class="page-title">', '</h1>' );
				the_archive_description( '<div class="taxonomy-description">', '</div>' );
				?>
            </div>
        </header><!-- .page-header -->
	<?php } ?>

	<?php if ( is_search() ) { ?>
        <header class="page-header archive-header">
            <div class="container">
                <h1 class="page-title">
		            <?php
		            /* translators: %s: search query. */
		            printf( esc_html__( 'Search Results for: %s', 'wp-blog' ), '<span>' . get_search_query() . '</span>' );
		            ?>
                </h1>
            </div>
        </header><!-- .page-header -->
	<?php } ?>


	<?php if ( is_home() || is_front_page() ) : ?>
        <div id="featured-content" class="container">
			<?php get_template_part( 'template-parts/content', 'featured' ); ?>
        </div>
	<?php endif; ?>


	<div id="content" class="site-content">
