<?php
/**
 * WP Blog Theme Customizer
 *
 * @package WP_Blog
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wp_blog_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'wp_blog_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'wp_blog_customize_partial_blogdescription',
		) );
	}

	// Load custom controls
	require get_template_directory() . '/inc/customizer-controls.php';

	$wp_customize->add_setting( 'logo_margin', array(
		'sanitize_callback' => 'wp_blog_sanitize_number_absint',
		'default' => 10,
	) );
	$wp_customize->add_control(
		'logo_margin',
		array(
			'type' => 'number',
			'label'      => esc_html__( 'Logo Margin Bottom', 'wp-blog' ),
			'description' => 'pixel unit',
			'section'    => 'title_tagline',
		)
	);

	$wp_customize->add_setting( 'primary_color' , array(
		'sanitize_callback'	=> 'sanitize_hex_color',
		'default'     => '#996515',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'primary_color', array(
		'label'        => esc_html__( 'Primary Color', 'wp-blog' ),
		'section'    => 'colors',
		'settings'   => 'primary_color',
	) ) );


	$wp_customize->add_panel( 'theme_options' ,
		array(
			'title'       => esc_html__( 'Theme Options', 'wp-blog' ),
			'description' => ''
		)
	);
	/**
	 * Featured Content
	 */

	$wp_customize->add_section( 'featured_section' ,
		array(
			'panel'       => 'theme_options',
			'title'       => esc_html__( 'Featured Content', 'wp-blog' ),
			'description' => esc_html__( 'Easily feature all posts with the "featured" tag or a tag of your choice.', 'wp-blog' ),
			'priority'     => 15
		)
	);

	$wp_customize->add_setting( 'featured_tags', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default' => 'featured',
	) );
	$wp_customize->add_control(
		'featured_tags',
		array(
			'type' => 'text',
			'label'      => esc_html__( 'Tag slug', 'wp-blog' ),
			'section'    => 'featured_section',
		)
	);
	$wp_customize->add_setting( 'featured_number', array(
		'sanitize_callback' => 'wp_blog_sanitize_number_absint',
		'default' => 10,
	) );
	$wp_customize->add_control(
		'featured_number',
		array(
			'type' => 'text',
			'label'      => esc_html__( 'Number post to show', 'wp-blog' ),
			'section'    => 'featured_section',
		)
	);

	$wp_customize->add_setting( 'hide_tag', array(
		'sanitize_callback' => 'wp_blog_checkbox_sanitize',
		'default'           => ''
	) );
	$wp_customize->add_control( 'hide_tag',
		array(
			'type'        => 'checkbox',
			'label'       => esc_html__('Exclude featured post in main loop', 'wp-blog'),
			'section'     => 'featured_section',
			'description' => ''
		)
	);


	/* Social */
	$wp_customize->add_section( 'social_media' ,
		array(
			'panel'       => 'theme_options',
			'title'       => esc_html__( 'Topbar Socials', 'wp-blog' ),
			'priority'     => 15
		)
	);
	$wp_customize->add_setting( 'facebook_url', array(
		'sanitize_callback' => 'esc_url_raw',
		'default' => '',
	) );
	$wp_customize->add_control(
		'facebook_url',
		array(
			'type' => 'text',
			'label'      => esc_html__( 'Facebook', 'wp-blog' ),
			'section'    => 'social_media',
		)
	);
	$wp_customize->add_setting( 'twitter_url', array(
		'sanitize_callback' => 'esc_url_raw',
		'default' => '',
	) );
	$wp_customize->add_control(
		'twitter_url',
		array(
			'type' => 'text',
			'label'      => esc_html__( 'Twitter', 'wp-blog' ),
			'section'    => 'social_media',
		)
	);
	$wp_customize->add_setting( 'gooogle_plus', array(
		'sanitize_callback' => 'esc_url_raw',
		'default' => '',
	) );
	$wp_customize->add_control(
		'gooogle_plus',
		array(
			'type' => 'text',
			'label'      => esc_html__( 'Google+', 'wp-blog' ),
			'section'    => 'social_media',
		)
	);
	$wp_customize->add_setting( 'pinterest_url', array(
		'sanitize_callback' => 'esc_url_raw',
		'default' => '',
	) );
	$wp_customize->add_control(
		'pinterest_url',
		array(
			'type' => 'text',
			'label'      => esc_html__( 'Pinterest', 'wp-blog' ),
			'section'    => 'social_media',
		)
	);
	$wp_customize->add_setting( 'tumblr_url', array(
		'sanitize_callback' => 'esc_url_raw',
		'default' => '',
	) );
	$wp_customize->add_control(
		'tumblr_url',
		array(
			'type' => 'text',
			'label'      => esc_html__( 'Tumblr', 'wp-blog' ),
			'section'    => 'social_media',
		)
	);
	$wp_customize->add_setting( 'reddit_url', array(
		'sanitize_callback' => 'esc_url_raw',
		'default' => '',
	) );
	$wp_customize->add_control(
		'reddit_url',
		array(
			'type' => 'text',
			'label'      => esc_html__( 'Reddit', 'wp-blog' ),
			'section'    => 'social_media',
		)
	);
	$wp_customize->add_setting( 'youtube_url', array(
		'sanitize_callback' => 'esc_url_raw',
		'default' => '',
	) );
	$wp_customize->add_control(
		'youtube_url',
		array(
			'type' => 'text',
			'label'      => esc_html__( 'Youtube', 'wp-blog' ),
			'section'    => 'social_media',
		)
	);
	$wp_customize->add_setting( 'linkedin_url', array(
		'sanitize_callback' => 'esc_url_raw',
		'default' => '',
	) );
	$wp_customize->add_control(
		'linkedin_url',
		array(
			'type' => 'text',
			'label'      => esc_html__( 'Linkedin', 'wp-blog' ),
			'section'    => 'social_media',
		)
	);
	$wp_customize->add_setting( 'instagram_url', array(
		'sanitize_callback' => 'esc_url_raw',
		'default' => '',
	) );
	$wp_customize->add_control(
		'instagram_url',
		array(
			'type' => 'text',
			'label'      => esc_html__( 'Instagram', 'wp-blog' ),
			'section'    => 'social_media',
		)
	);
	$wp_customize->add_setting( 'email_address', array(
		'sanitize_callback' => 'sanitize_email',
		'default' => '',
	) );
	$wp_customize->add_control(
		'email_address',
		array(
			'type' => 'text',
			'label'      => esc_html__( 'Email', 'wp-blog' ),
			'section'    => 'social_media',
		)
	);

	/* Single post */
	$wp_customize->add_section( 'single_post' ,
		array(
			'panel'       => 'theme_options',
			'title'       => esc_html__( 'Single Post', 'wp-blog' ),
			'priority'     => 15
		)
	);

	$wp_customize->add_setting( 'post_layout', array(
		'sanitize_callback' => 'wp_blog_sanitize_select',
		'default'           => 'right-sidebar'
	) );
	$wp_customize->add_control( 'post_layout',
		array(
			'type'        => 'select',
			'label'       => esc_html__('Post Layout', 'wp-blog'),
			'section'     => 'single_post',
			'choices' => array(
				'right-sidebar' => esc_html__('Right sidebar', 'wp-blog'),
				'left-sidebar' => esc_html__('Left sidebar', 'wp-blog'),
				'no-sidebar' => esc_html__('No sidebar', 'wp-blog'),
			)
		)
	);
	
	
	$wp_customize->add_setting( 'show_category', array(
		'sanitize_callback' => 'wp_blog_checkbox_sanitize',
		'default'           => ''
	) );
	$wp_customize->add_control( 'show_category',
		array(
			'type'        => 'checkbox',
			'label'       => esc_html__('Hide category after main title?', 'wp-blog'),
			'section'     => 'single_post',
			'description' => ''
		)
	);
	$wp_customize->add_setting( 'show_date', array(
		'sanitize_callback' => 'wp_blog_checkbox_sanitize',
		'default'           => ''
	) );
	$wp_customize->add_control( 'show_date',
		array(
			'type'        => 'checkbox',
			'label'       => esc_html__('Hide date after main title?', 'wp-blog'),
			'section'     => 'single_post',
			'description' => ''
		)
	);
	$wp_customize->add_setting( 'show_author', array(
		'sanitize_callback' => 'wp_blog_checkbox_sanitize',
		'default'           => ''
	) );
	$wp_customize->add_control( 'show_author',
		array(
			'type'        => 'checkbox',
			'label'       => esc_html__('Hide author after main title?', 'wp-blog'),
			'section'     => 'single_post',
			'description' => ''
		)
	);
	$wp_customize->add_setting( 'show_comment', array(
		'sanitize_callback' => 'wp_blog_checkbox_sanitize',
		'default'           => ''
	) );
	$wp_customize->add_control( 'show_comment',
		array(
			'type'        => 'checkbox',
			'label'       => esc_html__('Hide comment count after main title?', 'wp-blog'),
			'section'     => 'single_post',
			'description' => ''
		)
	);
	$wp_customize->add_setting( 'show_post_meta', array(
		'sanitize_callback' => 'wp_blog_checkbox_sanitize',
		'default'           => ''
	) );
	$wp_customize->add_control( 'show_post_meta',
		array(
			'type'        => 'checkbox',
			'label'       => esc_html__('Hide posted in and tagged below entry post?', 'wp-blog'),
			'section'     => 'single_post',
			'description' => ''
		)
	);
	$wp_customize->add_setting( 'show_author_box', array(
		'sanitize_callback' => 'wp_blog_checkbox_sanitize',
		'default'           => ''
	) );
	$wp_customize->add_control( 'show_author_box',
		array(
			'type'        => 'checkbox',
			'label'       => esc_html__('Hide author box below entry post?', 'wp-blog'),
			'section'     => 'single_post',
			'description' => ''
		)
	);


	// Newsletter
	$wp_customize->add_section( 'newsletter', array(
		'title' => esc_html__( 'Newsletter', 'wp-blog' ),
		'panel' => 'theme_options'
	));
	// Disable Newsletter
	$wp_customize->add_setting( 'newsletter_disable',
		array(
			'sanitize_callback' => 'wp_blog_checkbox_sanitize',
			'default'           => '',
		)
	);
	$wp_customize->add_control( 'newsletter_disable',
		array(
			'type'        => 'checkbox',
			'label'       => esc_html__('Hide Newsletter?', 'wp-blog'),
			'section'     => 'newsletter',
			'description' => esc_html__('Check this box to hide footer newsletter form.', 'wp-blog')
		)
	);
	$wp_customize->add_setting( 'newsletter_form_shortcode', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => ''
	) );
	$wp_customize->add_control( 'newsletter_form_shortcode',
		array(
			'label'       => esc_html__('MailChimp Form Shortcode', 'wp-blog'),
			'section'     => 'newsletter',
			'description' => ''
		)
	);
	$wp_customize->add_setting( 'newsletter_position', array(
		'sanitize_callback' => 'wp_blog_sanitize_select',
		'default'           => 'after-widget'
	) );
	$wp_customize->add_control( 'newsletter_position',
		array(
			'type'        => 'select',
			'label'       => esc_html__('Position', 'wp-blog'),
			'section'     => 'newsletter',
			'choices' => array(
				'before-widget' => esc_html__('Before Footer Widget', 'wp-blog'),
				'after-widget' => esc_html__('After Footer Widget', 'wp-blog'),
			)
		)
	);

	
	// Up sell
	$wp_customize->add_section( 'wp_blog_pro' ,
		array(
			'title'       => esc_html__( 'Upgrade to Pro', 'wp-blog' ),
			'description' => '',
			'priority'     => 10
		)
	);
	$wp_customize->add_setting( 'wpblog_pro_features', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wp_customize->add_control(
		new WP_Blog_Customize_Pro_Control(
			$wp_customize,
			'wpblog_pro_features',
			array(
				'label'      => esc_html__( 'WP BLog Pro Features', 'wp-blog' ),
				'description'   => '<span>Retina Logo</span><span>Sticky Header</span><span>Header Presets</span><span>Topbar search/cart icon</span><span>Header/Slider FullWidth</span><span>3 Promo boxes below slider</span><span>600+ Google Fonts</span><span>4 Post Listing Layouts</span><span>4 Article Listing Layouts</span><span>Custom Widgets</span><span>Social Position</span><span>Footer Instagram</span><span>Footer Widget Layout</span><span>Footer Copyright Editor</span><span>... and much more </span>',
				'section'    => 'wp_blog_pro',
			)
		)
	);
	$wp_customize->add_setting( 'wpblog_pro_links', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wp_customize->add_control(
		new WP_Blog_Customize_Pro_Control(
			$wp_customize,
			'wpblog_pro_links',
			array(
				'description'   => '<a target="_blank" class="wpblog-pro-buy-button" href="https://www.filathemes.com/downloads/wp-blog-pro/">Buy Now</a>', 'wp-blog',
				'section'    => 'wp_blog_pro',
			)
		)
	);

	$wp_customize->add_section( 'articles_listing_section' ,
		array(
			'panel'       => 'theme_options',
			'title'       => esc_html__( 'Articles Listing Layout', 'wp-blog' ),
			'priority'     => 20
		)
	);

	$wp_customize->add_setting( 'articles_listing_layout', array(
		'sanitize_callback' => 'wp_blog_sanitize_select',
		'default' => 'layout_1',
	) );

	
	$wp_customize->add_control(
		new WP_Blog_Customize_Radio_Image_Control(
			$wp_customize,
			'articles_listing_layout',
			array(
				'choices'     =>array(
					'layout_1' =>  array(
						'img'   => get_template_directory_uri() . '/assets/images/layout1.png',
						'label' => esc_html__( 'Layout 1', 'wp-blog' ),
					)
				),
				'label'      => esc_html__( 'Homepage articles listing layout', 'wp-blog' ),
				'description' => esc_html__( 'Upgrade to Pro to have more post layouts.', 'wp-blog' ),
				'section'    => 'articles_listing_section',
			)
		)
	);
	
	function wp_blog_checkbox_sanitize( $input ){
		//returns true if checkbox is checked
		return ( ( $input == 1 ) ? 1 : '' );
	}

	function wp_blog_sanitize_number_absint( $number, $setting ) {
		// Ensure $number is an absolute integer (whole number, zero or greater).
		$number = absint( $number );

		// If the input is an absolute integer, return it; otherwise, return the default
		return ( $number ? $number : $setting->default );
	}

	function wp_blog_sanitize_select( $input, $setting ) {

		// Ensure input is a slug.
		$input = sanitize_key( $input );

		// Get list of choices from the control associated with the setting.
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it; otherwise, return the default.
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}

}
add_action( 'customize_register', 'wp_blog_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function wp_blog_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function wp_blog_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function wp_blog_customize_preview_js() {
	wp_enqueue_script( 'wp-blog-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'wp_blog_customize_preview_js' );


/**
 * Load customizer css
 */
function wp_blog_customizer_load_css(){
	wp_enqueue_style( 'wp-blog-customizer', get_template_directory_uri() . '/assets/css/customizer.css' );
}
add_action('customize_controls_print_styles', 'wp_blog_customizer_load_css');