<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package WP_Blog
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function wp_blog_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	return $classes;
}
add_filter( 'body_class', 'wp_blog_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function wp_blog_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'wp_blog_pingback_header' );

if ( !is_admin() ) {
	function wp_blog_custom_excerpt_length( $length ) {
		return 20;
	}

	add_filter( 'excerpt_length', 'wp_blog_custom_excerpt_length', 999 );

	function wp_blog_excerpt_more( $more ) {
		return '&hellip;';
	}

	add_filter( 'excerpt_more', 'wp_blog_excerpt_more' );
}

function wp_blog_search_form( $form ) {
	$form = '<form role="search" method="get" id="searchform" class="search-form" action="' . esc_url( home_url( '/' ) ) . '" >
    <label for="s">
    	<input type="text" value="' . get_search_query() . '" placeholder="' . esc_attr__( 'Search &hellip;', 'wp-blog' ) . '" name="s" id="s" />
    </label>
    <button type="submit" class="search-submit">
        <i class="fa fa-search"></i>
    </button>
    </form>';

	return $form;
}
add_filter( 'get_search_form', 'wp_blog_search_form' );


/* Custom style */
function wp_blog_custom_style(){
	$custom_css = '';
	$primary   = esc_attr( get_theme_mod( 'primary_color', '#996515' ) );
	$logo_margin = absint( get_theme_mod( 'logo_margin', '10' ) );

	$custom_css .= "
		 a:active, a:hover,
		 .site-info a,
		 .pagination .nav-links .current,
		 .single .entry-footer a,
		 .site-topbar nav ul li a:hover,
		 .site-topbar nav ul li.current-menu-item a,
		 .site-topbar nav ul li.current-menu-ancestor a,
		 #featured_posts .item .slide-container .slide-content .slide-inside .slide-item .readmore:hover,
		 .blog-posts .post .entry-content .entry-title a:hover,
		 .blog-posts .post .entry-content .posted-in a:hover,
		 .blog-posts .post .entry-content a.readmore:hover,
		 .pagination .nav-links .page-numbers:hover,
		 .social-media-gadget ul li a:hover
		 {
			color: {$primary};
		}
		
		.blog-posts .post .entry-content a.readmore,
		#featured_posts .item .slide-container .slide-content .slide-inside .slide-item .readmore {
			border-bottom-color: {$primary};
		}
		.pagination .nav-links .page-numbers:hover,
		.pagination .nav-links .current,
		.widget_tag_cloud a:hover,
		 .single .entry-content blockquote {
			border-color: {$primary};
		}
		button:hover, input[type=\"button\"]:hover, input[type=\"reset\"]:hover, input[type=\"submit\"]:hover,
		.single .entry-meta .posted-in a,
		.widget_tag_cloud a:hover ,
		#to-top,
		.search-form .search-submit:hover {
			background-color: {$primary};
		}
		
		.site-branding .custom-logo-link { margin-bottom: {$logo_margin}px; }
	";
	return $custom_css;
}

function wp_blog_exclude_tags( $query ) {
	if ( $query->is_home() && $query->is_main_query() ) {
		$tag_name = esc_attr( get_theme_mod('featured_tags') );
		$hide_tag = esc_attr( get_theme_mod('hide_tag', '1') );
		$tag = get_term_by('slug', $tag_name, 'post_tag');
		if ( $hide_tag == 1 && !empty( $tag ) ) {
			$query->set( 'tag__not_in', array( $tag->term_id ) );
		}
	}
}
add_action( 'pre_get_posts', 'wp_blog_exclude_tags' );



add_action( 'tgmpa_register', 'wp_blog_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register five plugins:
 * - one included with the TGMPA library
 * - two from an external source, one from an arbitrary source, one from a GitHub repository
 * - two from the .org repo, where one demonstrates the use of the `is_callable` argument
 *
 * The variables passed to the `tgmpa()` function should be:
 * - an array of plugin arrays;
 * - optionally a configuration array.
 * If you are not changing anything in the configuration array, you can remove the array and remove the
 * variable from the function call: `tgmpa( $plugins );`.
 * In that case, the TGMPA default settings will be used.
 *
 * This function is hooked into `tgmpa_register`, which is fired on the WP `init` action on priority 10.
 */
function wp_blog_register_required_plugins() {
	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(

		// This is an example of how to include a plugin from the WordPress Plugin Repository.
		array(
			'name'      => 'MailChimp for WordPress',
			'slug'      => 'mailchimp-for-wp',
			'required'  => false,
		),

		array(
			'name'      => 'One Click Demo Import',
			'slug'      => 'one-click-demo-import',
			'required'  => false,
		),

		array(
			'name'      => 'Mega Menu Plugin for WordPress',
			'slug'      => 'easymega',
			'required'  => false,
		),


	);

	/*
	 * Array of configuration settings. Amend each line as needed.
	 *
	 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
	 * strings available, please help us make TGMPA even better by giving us access to these translations or by
	 * sending in a pull-request with .po file(s) with the translations.
	 *
	 * Only uncomment the strings in the config array if you want to customize the strings.
	 */
	$config = array(
		'id'           => 'wp-blog',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.


	);

	tgmpa( $plugins, $config );
}

function ocdi_import_files() {
	return array(
		array(
			'import_file_name'             => 'WP Blog Demo Import',
			'local_import_file'            => trailingslashit( get_template_directory() ) . 'assets/dummy-data/demo-content.xml',
			'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'assets/dummy-data/widgets.wie',
			'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'assets/dummy-data/customizer.dat'
		)
	);
}
add_filter( 'pt-ocdi/import_files', 'ocdi_import_files' );
function ocdi_plugin_page_setup( $default_settings ) {
	$default_settings['page_title']  = esc_html__( 'Demo Data Import' , 'wp-blog' );
	return $default_settings;
}
add_filter( 'pt-ocdi/plugin_page_setup', 'ocdi_plugin_page_setup' );

/**
 * Footer Copyright
 */
function wp_blog_footer_info() {
	echo sprintf( esc_html__( 'Copyright &copy; %1$s %2$s - %3$s theme by FilaThemes', 'wp-blog' ), date_i18n( __('Y', 'wp-blog') ), '<a href="'.esc_url( home_url( '/' ) ).'" title="'.esc_attr( get_bloginfo( 'name', 'display' ) ).'">'.esc_html( get_bloginfo( 'name', 'display' ) ).'</a>', '<a target="_blank" href="http://filathemes.com/wp-blog">WP Blog</a>' );
}
add_action( 'wp_blog_footer_copyright', 'wp_blog_footer_info' );